@@ -5,7 +5,7 @@ extends 'NewsExtractor::TXExtractor';
 use Mojo::Transaction::HTTP;
 use Types::Standard qw( InstanceOf HashRef ArrayRef );
 use Mojo::JSON qw(from_json);
-use Importer 'NewsExtractor::TextUtil' => qw(u);
+use Importer 'NewsExtractor::TextUtil' => qw(u remove_control_characters);
 
 has tx => (
     required => 1, is => 'ro',
@@ -33,23 +33,23 @@ sub _build_schema_ld {
 
 sub journalist {
     my ($self) = @_;
-    return u($self->schema_ld->{author}{name});
+    return remove_control_characters(u($self->schema_ld->{author}{name}));
 }
 
 sub headline {
     my ($self) = @_;
-    return u($self->schema_ld->{headline});
+    return remove_control_characters(u($self->schema_ld->{headline}));
 }
 
 sub dateline {
     my ($self) = @_;
-    return u($self->schema_ld->{datePublished});
+    return remove_control_characters(u($self->schema_ld->{datePublished}));
 }
 
 sub content_text {
     my ($self) = @_;
     my $text = $self->schema_ld->{articleBody} // $self->schema_ld->{description} // '';
-    return u($text);
+    return remove_control_characters(u($text));
 }
 
 1;
